==> web-11.0.2.tgz: package/lib/input/FileInp.js <==
import * as immutable from "immutable";
import * as React from "react";
import { Button } from "../button/index";
import { SvgIcon } from "../my-icon/index";
let createId = 0;
class FileInp extends React.PureComponent {
    constructor(prop) {
        super(prop);
        this.getFiles = () => {
            const obj = {
                upFiles: this.state.upFiles.map((val) => val.file).toArray(),
                hasFile: this.state.hasFile.toArray()
            };
            return obj;
        };
        this.changeFn = (e) => {
            const { fileTypeMatch, multiply } = this.props;
            const dom = e.currentTarget;
            const file = dom.files;
            const fileName = file[0].name.split(".");
            const type = fileName[fileName.length - 1];
            if (fileTypeMatch && !fileTypeMatch.split(",").includes(type)) {
                return;
            }
            const item = {
                id: createId++,
                file: file[0],
            };
            this.setState((pre) => ({
                upFiles: multiply
                    ? pre.upFiles.push(item)
                    : pre.upFiles.clear().push(item),
            }), () => {
                dom.value = "";
                const { upFiles } = this.state;
                const { dataSet, name, changeFn } = this.props;
                changeFn && changeFn(upFiles, name, dataSet);
            });
        };
        this.removeFileItem = (e) => {
            const dom = e.currentTarget;
            const type = dom.dataset.type;
            const index = +dom.dataset.index;
            const { removeFIleFn } = this.props;
            if (type === "upFile") {
                this.setState((pre) => ({
                    upFiles: pre.upFiles.delete(index),
                }), () => {
                    const { upFiles } = this.state;
                    const { name } = this.props;
                    removeFIleFn && removeFIleFn(upFiles, name, type);
                });
            }
            else {
                this.setState((pre) => ({
                    hasFile: pre.hasFile.delete(index),
                }), () => {
                    const { upFiles } = this.state;
                    const { name } = this.props;
                    removeFIleFn && removeFIleFn(upFiles, name, type);
                });
            }
        };
        const { bindGetUpAndHasFiles } = prop;
        bindGetUpAndHasFiles && bindGetUpAndHasFiles(this.getFiles);
        this.state = {
            upFiles: immutable.fromJS([]),
            hasFile: immutable.List(prop.hasFiles ? prop.hasFiles : []),
            preHasFiles: prop.hasFiles
        };
    }
    static getDerivedStateFromProps(nextProps, preState) {
        if (nextProps.hasFiles !== preState.preHasFiles) {
            return {
                preHasFiles: nextProps.hasFiles,
                hasFile: immutable.List(nextProps.hasFiles ? nextProps.hasFiles : []),
                upFiles: immutable.List()
            };
        }
        return null;
    }
    getInpTit() {
        const { children } = this.props;
        const lab = children ? React.createElement("span", { className: "lab-tit" }, children) : "";
        return lab;
    }
    getHasFile() {
        const { hasFile } = this.state;
        const { hasFilesIdField, hasFilesTextField, width, hasFilesUrlField } = this.props;
        const style = width ? { width: width } : undefined;
        return (React.createElement("div", { className: "has-files", style: style }, hasFile.map((val, index) => (React.createElement("span", { className: "file-item", key: val[hasFilesIdField] },
            React.createElement("a", { style: { color: "#536ec2" }, download: val[hasFilesTextField], href: val[hasFilesUrlField], rel: "noreferrer" }, val[hasFilesTextField]),
            React.createElement("span", { className: "j-del", onClick: this.removeFileItem, "data-type": "hasFile", "data-index": index },
                React.createElement(SvgIcon, { className: "close" })))))));
    }
    render() {
        const { name, dataSet, className, width, norequire, disabled, multiply, hasFiles } = this.props;
        const { upFiles } = this.state;
        const style = width ? { width: width } : undefined;
        const noFill = norequire || disabled ? false : !upFiles.size;
        const requireName = noFill ? "no-fill" : "";
        return (React.createElement("div", { className: `g-file-box ${className}` },
            this.getInpTit(),
            React.createElement("div", null,
                hasFiles ? this.getHasFile() : null,
                React.createElement("div", { className: "j-file" },
                    React.createElement(Button, { disabled: disabled }, "\u6587\u4EF6\u4E0A\u4F20"),
                    React.createElement("input", { className: "file-inp", name: name, type: "file", disabled: disabled, "data-set": dataSet, onChange: this.changeFn })),
                React.createElement("div", { className: `up-files ${requireName}`, style: style, "data-tit": multiply ? "多文件..." : "单文件..." }, upFiles.map((val, index) => (React.createElement("span", { className: "file-item", key: val.id },
                    React.createElement("span", null, val.file.name),
                    React.createElement("span", { className: "j-del", onClick: this.removeFileItem, "data-type": "upFile", "data-index": index },
                        React.createElement(SvgIcon, { className: "close" })))))))));
    }
}
FileInp.defaultProps = {
    styleName: "normal",
    hasFilesTextField: "text",
    hasFilesIdField: "id",
    hasFilesUrlField: "url"
};
export default FileInp;

==> web-11.1.0.tgz: package/lib/input/FileInp.js <==
import * as immutable from "immutable";
import * as React from "react";
import { Button } from "../button/index";
import { SvgIcon } from "../my-icon/index";
let createId = 0;
class FileInp extends React.PureComponent {
    constructor(prop) {
        super(prop);
        this.getFiles = () => {
            const obj = {
                upFiles: this.state.upFiles.map((val) => val.file).toArray(),
                hasFile: this.state.hasFile.toArray()
            };
            return obj;
        };
        this.changeFn = (e) => {
            const { fileTypeMatch, multiply } = this.props;
            const dom = e.currentTarget;
            const file = dom.files;
            const fileName = file[0].name.split(".");
            const type = fileName[fileName.length - 1];
            if (fileTypeMatch && !fileTypeMatch.split(",").includes(type)) {
                return;
            }
            const item = multiply ? [...file].map((val) => ({
                id: createId++,
                file: val,
            })) : [{
                    id: createId++,
                    file: file[0],
                }];
            this.setState((pre) => ({
                upFiles: multiply
                    ? pre.upFiles.push(...item)
                    : pre.upFiles.clear().push(item[0]),
            }), () => {
                dom.value = "";
                const { upFiles } = this.state;
                const { dataSet, name, changeFn } = this.props;
                changeFn && changeFn(upFiles, name, dataSet);
            });
        };
        this.removeFileItem = (e) => {
            const dom = e.currentTarget;
            const type = dom.dataset.type;
            const index = +dom.dataset.index;
            const { removeFIleFn } = this.props;
            if (type === "upFile") {
                this.setState((pre) => ({
                    upFiles: pre.upFiles.delete(index),
                }), () => {
                    const { upFiles } = this.state;
                    const { name } = this.props;
                    removeFIleFn && removeFIleFn(upFiles, name, type);
                });
            }
            else {
                this.setState((pre) => ({
                    hasFile: pre.hasFile.delete(index),
                }), () => {
                    const { upFiles } = this.state;
                    const { name } = this.props;
                    removeFIleFn && removeFIleFn(upFiles, name, type);
                });
            }
        };
        const { bindGetUpAndHasFiles } = prop;
        bindGetUpAndHasFiles && bindGetUpAndHasFiles(this.getFiles);
        this.state = {
            upFiles: immutable.fromJS([]),
            hasFile: immutable.List(prop.hasFiles ? prop.hasFiles : []),
            preHasFiles: prop.hasFiles
        };
    }
    static getDerivedStateFromProps(nextProps, preState) {
        if (nextProps.hasFiles !== preState.preHasFiles) {
            return {
                preHasFiles: nextProps.hasFiles,
                hasFile: immutable.List(nextProps.hasFiles ? nextProps.hasFiles : []),
                upFiles: immutable.List()
            };
        }
        return null;
    }
    getInpTit() {
        const { children } = this.props;
        const lab = children ? React.createElement("span", { className: "lab-tit" }, children) : "";
        return lab;
    }
    getHasFile() {
        const { hasFile } = this.state;
        const { hasFilesIdField, hasFilesTextField, width, hasFilesUrlField } = this.props;
        const style = width ? { width: width } : undefined;
        return (React.createElement("div", { className: "has-files", style: style }, hasFile.map((val, index) => (React.createElement("span", { className: "file-item", key: val[hasFilesIdField] },
            React.createElement("a", { style: { color: "#536ec2" }, download: val[hasFilesTextField], href: val[hasFilesUrlField], rel: "noreferrer" }, val[hasFilesTextField]),
            React.createElement("span", { className: "j-del", onClick: this.removeFileItem, "data-type": "hasFile", "data-index": index },
                React.createElement(SvgIcon, { className: "close" })))))));
    }
    render() {
        const { name, dataSet, className, width, norequire, disabled, multiply, hasFiles, icon } = this.props;
        const { upFiles } = this.state;
        const style = width ? { width: width } : undefined;
        const noFill = norequire || disabled ? false : !upFiles.size;
        const requireName = noFill ? "no-fill" : "";
        const iconCom = icon ? React.createElement(React.Fragment, null,
            React.createElement(SvgIcon, { className: icon }),
            "\u00A0") : null;
        return (React.createElement("div", { className: `g-file-box ${className}` },
            this.getInpTit(),
            React.createElement("div", null,
                hasFiles ? this.getHasFile() : null,
                React.createElement("div", { className: "j-file" },
                    React.createElement(Button, { disabled: disabled },
                        iconCom,
                        "\u9009\u62E9\u6587\u4EF6"),
                    React.createElement("input", { className: "file-inp", name: name, multiple: multiply, type: "file", disabled: disabled, "data-set": dataSet, onChange: this.changeFn })),
                React.createElement("div", { className: `up-files ${requireName}`, style: style, "data-tit": multiply ? "多文件..." : "单文件..." }, upFiles.map((val, index) => (React.createElement("span", { className: "file-item", key: val.id },
                    React.createElement("span", null,
                        iconCom,
                        val.file.name),
                    React.createElement("span", { className: "j-del", onClick: this.removeFileItem, "data-type": "upFile", "data-index": index },
                        React.createElement(SvgIcon, { className: "close" })))))))));
    }
}
FileInp.defaultProps = {
    styleName: "normal",
    hasFilesTextField: "text",
    hasFilesIdField: "id",
    hasFilesUrlField: "url"
};
export default FileInp;
